/*-------------------------------------------------------------------------------------------------------------------------------------------
 * tables24h.h - WC24H tables
 *
 * Copyright (c) 2018 Frank Meyer - frank(at)fli4l.de
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *-------------------------------------------------------------------------------------------------------------------------------------------
 */
#if WCLOCK24H == 1

#ifndef TABLES_H
#define TABLES_H

#include <stdint.h>

#define WC_ROWS                 16                              // 16 rows
#define WC_COLUMNS              18                              // 18 columns

#define DISPLAY_MODES_COUNT     21                              // count of different display modes
#define HOUR_COUNT              24                              // 24 plus one to distinguish between before and after full hour
#define MINUTE_COUNT            60

enum HourMode
{
    HM_0,                                                       // 0 = Mode 0: "leer, fuer Temperaturanzeige"
    HM_1,                                                       // 1 = Mode 1: "MM - HH (12)"
    HM_2,                                                       // 2 = Mode 3: "MM - HH UHR (12) NACHTS"
    HM_3,                                                       // 3 = Mode 4: "MM - HH UHR (24)"
    HM_4,                                                       // 4 = Mode 5: "HH UHR (12) - MM"
    HM_5,                                                       // 5 = Mode 6: "HH UHR 24) - MM"
    HM_6,                                                       // 6 = Mode 7: "MITTERNACHT (0 UHR)"
    HOUR_MODES_COUNT                                            // Number of HourModes
};

enum MinuteMode
{
    MM_1,                                                       //  0 = Mode  1: "MM NACH"
    MM_2,                                                       //  1 = Mode  2: "MM MINUTEN NACH"
    MM_3,                                                       //  2 = Mode  3: "OSSI - MM MINUTEN NACH (VIERTEL NACH, HALB, VIERTEL VOR)"
    MM_4,                                                       //  3 = Mode  4: "OESI - MINUTEN NACH (VIERTEL NACH, HALB, DREIVIERTEL)"
    MM_5,                                                       //  4 = Mode  5: "RHEIN/ RUHR - MINUTEN NACH (VIERTEL, HALB, DREIVIERTEL)"
    MM_6,                                                       //  5 = Mode  6: "SCHWABEN - MM MINUTEN NACH (VIERTEL NACH, HALB, DREIVIERTEL)"
    MM_7,                                                       //  6 = Mode  7: "WESSI - MM MINUTEN NACH (VIERTEL, HALB, DREIVIERTEL)"
    MM_8,                                                       //  7 = Mode  8: "TIROL - VIERTEL NACH, aber DREIVIERTEL"
    MM_9,                                                       //  8 = Mode  9: "MM"
    MM_10,                                                      //  9 = Mode 10: "UND MM MINUTEN"
    MM_11,                                                      // 10 = Mode 11: "MM MINUTEN VOR"
    MM_12,                                                      // 11 = Mode 12: "JESTER"
    MM_13,                                                      // 12 = Mode 13: "TEMPERATUR CC GRAD"
    MINUTE_MODES_COUNT                                          // Number of MinuteModes
};

enum WordPos
{
    WP_END_OF_WORDS,                                            //  0 = ""
    WP_ES,                                                      //  1 = "ES"
    WP_IT,                                                      //  2 = "IT"
    WP_IST,                                                     //  3 = "IST"
    WP_IS,                                                      //  4 = "IS"
    WP_VIERTEL_1,                                               //  5 = "VIERTEL"
    WP_EIN_1,                                                   //  6 = "EIN"
    WP_EINS_1,                                                  //  7 = "EINS"
    WP_IN,                                                      //  8 = "IN"
    WP_DREI_1,                                                  //  9 = "DREI"
    WP_EIN_2,                                                   // 10 = "EIN"
    WP_EINE_1,                                                  // 11 = "EINE"
    WP_EINER,                                                   // 12 = "EINER"
    WP_SECH_1,                                                  // 13 = "SECH"
    WP_SECHS_1,                                                 // 14 = "SECHS"
    WP_SIEB_1,                                                  // 15 = "SIEB"
    WP_SIEBEN_1,                                                // 16 = "SIEBEN"
    WP_ELF_1,                                                   // 17 = "ELF"
    WP_FUENF_1,                                                 // 18 = "FNF"
    WP_NEUN_1,                                                  // 19 = "NEUN"
    WP_VIER_1,                                                  // 20 = "VIER"
    WP_ACHT_1,                                                  // 21 = "ACHT"
    WP_NULL_1,                                                  // 22 = "NULL"
    WP_ZWEI_1,                                                  // 23 = "ZWEI"
    WP_ZWOELF_1,                                                // 24 = "ZWLF"
    WP_ZEHN_1,                                                  // 25 = "ZEHN"
    WP_UND_1,                                                   // 26 = "UND"
    WP_ZWANZIG_1,                                               // 27 = "ZWANZIG"
    WP_VIERZIG_1,                                               // 28 = "VIERZIG"
    WP_DREISSIG_1,                                              // 29 = "DREISSIG"
    WP_FUENFZIG_1,                                              // 30 = "FNFZIG"
    WP_UHR_1,                                                   // 31 = "UHR"
    WP_MINUTE_1,                                                // 32 = "MINUTE"
    WP_MINUTEN_1,                                               // 33 = "MINUTEN"
    WP_VOR_1,                                                   // 34 = "VOR"
    WP_UND_2,                                                   // 35 = "UND"
    WP_NACH_1,                                                  // 36 = "NACH"
    WP_EIN_3,                                                   // 37 = "EIN"
    WP_DREIVIERTEL,                                             // 38 = "DREIVIERTEL"
    WP_VIERTEL_2,                                               // 39 = "VIERTEL"
    WP_HALB,                                                    // 40 = "HALB"
    WP_SIEB_2,                                                  // 41 = "SIEB"
    WP_SIEBEN_2,                                                // 42 = "SIEBEN"
    WP_NEUN_2,                                                  // 43 = "NEUN"
    WP_NULL_2,                                                  // 44 = "NULL"
    WP_ZWEI_2,                                                  // 45 = "ZWEI"
    WP_EIN_4,                                                   // 46 = "EIN"
    WP_EINE_2,                                                  // 47 = "EINE"
    WP_FUENF_2,                                                 // 48 = "FNF"
    WP_SECH_2,                                                  // 49 = "SECH"
    WP_SECHS_2,                                                 // 50 = "SECHS"
    WP_NACH_2,                                                  // 51 = "NACH"
    WP_ACHT_2,                                                  // 51 = "ACHT"
    WP_VIER_2,                                                  // 52 = "VIER"
    WP_DREI_2,                                                  // 53 = "DREI"
    WP_EIN_5,                                                   // 54 = "EIN"
    WP_EINS_2,                                                  // 55 = "EINS"
    WP_UND_3,                                                   // 56 = "UND"
    WP_ELF_2,                                                   // 57 = "ELF"
    WP_ZEHN_2,                                                  // 58 = "ZEHN"
    WP_ZWANZIG_2,                                               // 59 = "ZWANZIG"
    WP_GRAD,                                                    // 60 = "GRAD"
    WP_DREISSIG_2,                                              // 61 = "DREISSIG"
    WP_VIERZIG_2,                                               // 62 = "VIERZIG"
    WP_ZWOELF_2,                                                // 63 = "ZWLF"
    WP_FUENFZIG_2,                                              // 64 = "FNFZIG"
    WP_MINUTE_2,                                                // 65 = "MINUTE"
    WP_MINUTEN_2,                                               // 66 = "MINUTEN"
    WP_UHR_2,                                                   // 67 = "UHR"
    WP_FRUEH,                                                   // 68 = "FRH"
    WP_VOR_2,                                                   // 69 = "VOR"
    WP_ABENDS,                                                  // 70 = "ABENDS"
    WP_MITTERNACHT,                                             // 71 = "MITTERNACHT"
    WP_NACH_3,                                                  // 72 = "NACH"
    WP_NACHTS,                                                  // 73 = "NACHTS"
    WP_MORGENS,                                                 // 74 = "MORGENS"
    WP_WARM,                                                    // 75 = "WARM"
    WP_MITTAGS,                                                 // 76 = "MITTAGS"
    WP_COUNT,                                                   // number of words
};

#endif // TABLES_H
#endif // WCLOCK24H == 1
